==> kirigami-6.22.0-1.gpkg.tar: image/usr/src/debug/kde-frameworks/kirigami-6.22.0/kirigami-6.22.0_build/src/.qt/rcc/qrc_qmake_org_kde_kirigami.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0x7d,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x8c,0xb,0x9d,0x1b,0x0,0xd6,0xe0,0x5e,0x1e,0x10,0x77,0x1b,
  0x47,0x7b,0x89,0x9b,0xac,0xf8,0x84,0x26,0xa9,0x4f,0xb4,0x98,0x29,0x26,0xc0,0xc,
  0x0,0x6c,0xa,0xbd,0xaa,0xd6,0x55,0x55,0xf8,0xea,0xaa,0x54,0x0,0x57,0x0,0x57,
  0x0,0xd1,0x19,0x95,0x8,0xe3,0x2d,0x33,0x33,0x4e,0xbe,0xb8,0xda,0x3e,0x4a,0xce,
  0xcd,0x4f,0xda,0xd0,0x5b,0x79,0x2a,0xdc,0xde,0x47,0xe2,0xc9,0x19,0x7f,0xf6,0xe,
  0x9a,0xda,0x5a,0x35,0xdf,0xb5,0x8c,0x29,0xd9,0xd9,0xa8,0x72,0x50,0xe4,0xd5,0x4e,
  0x13,0xb3,0x99,0x46,0x29,0xb5,0x31,0x47,0x45,0x86,0x5b,0x6b,0x93,0xc2,0x63,0xe2,
  0xe6,0xc2,0xd7,0x29,0x8a,0xdc,0x14,0x67,0xa,0xf9,0x59,0x54,0xed,0x13,0x55,0xf0,
  0xdd,0x6d,0x6f,0xcf,0xb3,0x92,0x29,0x99,0xb2,0x1a,0x97,0xb6,0x2f,0xed,0xf6,0xc7,
  0x36,0x73,0x37,0xb4,0xd1,0x2c,0x54,0xc,0x8c,0xdc,0x7a,0x79,0x43,0xa6,0x69,0x4b,
  0xfa,0x8d,0x93,0xf6,0x2f,0xe9,0x52,0xf2,0x17,0xf9,0xf3,0xfb,0x74,0x23,0x8a,0x71,
  0x6b,0x9a,0x62,0x62,0xfa,0x53,0x5e,0xa,0xca,0x1,0x2a,0x81,0x8b,0xce,0x13,0x53,
  0x50,0x96,0x65,0xc1,0x77,0xab,0xb3,0x91,0x35,0x47,0x56,0xc2,0xfd,0x82,0xf6,0x35,
  0xaa,0x9b,0x41,0xa7,0x76,0xad,0xda,0xa9,0xa4,0xf6,0x9f,0x1,0x0,0x41,0xef,0xa5,
  0x94,0x89,0x6d,0xbb,0xc6,0xa1,0x4b,0x15,0x32,0x49,0x2d,0xe,0xe1,0x6,0xd9,0xd6,
  0xce,0x30,0x6d,0x3f,0x9c,0xa0,0x3d,0xb4,0x98,0xb6,0xb,0xb4,0x3b,0xc6,0x1,0x2,
  0xd8,0x6e,0xde,0x7b,0x49,0x4a,0x77,0x8,0x61,0xaf,0xeb,0xc,0xbd,0xfc,0xe8,0xef,
  0x44,0x9f,0x73,0x5b,0x88,0xa2,0x2b,0xbc,0x2e,0xda,0x9d,0xe3,0x8,0xfd,0xa2,0x46,
  0xe0,0x42,0x95,0x72,0x2b,0x1b,0xb9,0xa3,0xa4,0xb4,0xec,0x91,0x6e,0xf0,0x5e,0x19,
  0x81,0x6c,0x67,0x14,0x35,0xdd,0x1f,0x92,0x8e,0xb6,0xf9,0x43,0xb6,0x4f,0x73,0x23,
  0xad,0xd7,0xab,0xdd,0x27,0xbc,0xb2,0xed,0xb1,0xa7,0xfb,0xb3,0xf9,0x31,0xe3,0x92,
  0x1c,0xfe,0xa2,0x24,0x96,0xbc,0xd1,0xbd,0x61,0x7e,0x1b,0xdb,0x7c,0x79,0xa5,0xe4,
  0x4f,0x43,0x9b,0x85,0xcf,0xd1,0xd8,0x9e,0xcc,0x79,0x71,0xf3,0x87,0x22,0x4c,0x17,
  0xbd,0x29,0x68,0x1b,0xb,0x35,0x93,0xfc,0xc6,0xa8,0xb,0x69,0x6d,0x71,0x2b,0xad,
  0xf1,0x59,0xeb,0x8d,0xb4,0x6e,0x2e,0x80,0xf7,0xa8,0x81,0x12,0xd,0xc9,0x8c,0x24,
  0x49,0x65,0xe3,0x30,0x44,0x40,0x1c,0x45,0xe3,0x36,0x31,0x18,0xc8,0x31,0x22,0xd,
  0x22,0x35,0x23,0x23,0x41,0x14,0x26,0x49,0xa,0xcb,0x1,0x59,0xcb,0x82,0x1,0xa8,
  0x50,0x2b,0xcc,0x75,0xf3,0xe1,0x16,0x8d,0x76,0x5f,0xc5,0x83,0xfa,0x40,0x3f,0x21,
  0x37,0x14,0x49,0x85,0xff,0xc5,0x8b,0x7b,0xa5,0xc2,0x77,0x14,0xa8,0x10,0x4e,0xe9,
  0x2d,0x30,0xaf,0xd8,0xc1,0x4d,0x38,0x36,0xfc,0x3b,0x43,0xf5,0x62,0x88,0x1f,0x75,
  0xe2,0x1a,0xca,0xa7,0x2d,0x77,0xbf,0xc1,0xdf,0xc0,0x1d,0x95,0x44,0x44,0x51,0x2,
  0xc2,0x89,0x5e,0x50,0x54,0x99,0xb4,0x5b,0x77,0x3a,0x4c,0x6,0xc2,0x70,0x21,0xd7,
  0x46,0x96,0xe1,0x25,0x4c,0x51,0x43,0xd3,0x90,0xf2,0xd4,0x85,0xfb,0xf6,0xb8,0x83,
  0xf9,0x91,0x92,0xf0,0x8f,0x8,0x41,0xe7,0x88,0x4,0x76,0xb0,0xa,0xb5,0xdc,0xb9,
  0xe1,0x8c,0x13,0xad,0x24,0x89,0xc3,0x31,0x0,0x1b,0x20,0x51,0x3f,0x61,0x20,0x39,
  0x18,0x58,0x6e,0x2,0xe2,0x39,0xf8,0xb,0x63,0x3e,0xc1,0x90,0x16,0x49,0x86,0xf7,
  0x8c,0x66,0x6b,0xcc,0x5b,0xf2,0xce,0x9f,0x8a,0x3f,0x88,0x7f,0x35,0xfb,0x9,0xa,
  0x2c,0xf9,0xd5,0x20,0xa,0x5,0x77,0xa,0x11,0x90,0x70,0xf6,0xe,0x3b,0xb1,0xe1,
  0x92,0x7c,0x64,0xaa,0x70,0xd9,0x48,0x55,0xb3,0xc5,0x99,0xc2,0xeb,0x18,0xc,0x91,
  0x71,0xfd,0xbc,0x5d,0x73,0x9a,0x42,0xea,0x6e,0x27,0x69,0x98,0xa9,0xa4,0xf1,0xc5,
  0x98,0x1f,0xcd,0xb4,0x8,0xb0,0x83,0xe5,0x1d,0x27,0x7f,0x2b,0x5d,0xa2,0x14,0x8e,
  0x53,0x57,0x2d,0xd9,0x3,0x2,0x12,0xc8,0x24,0xee,0x74,0x9e,0xdd,0x8a,0x91,0x39,
  0x55,0x23,0x41,0xd8,0x8e,0xae,0x43,0x90,0x8e,0xb4,0xa0,0xd4,0x72,0x5f,0x3b,0x5e,
  0x48,0x34,0xa7,0xd2,0x52,0xb6,0x77,0xbc,0x78,0xf1,0x2a,0xb3,0x28,0x66,0x96,0xc0,
  0x60,0xbe,0x9d,0xb3,0x31,0x7f,0xc3,0xa7,0x22,0x30,0x2f,0x30,0x2a,0xd0,0xb7,0x23,
  0xe8,0xad,0x86,0x9d,0x6c,0x22,0xd8,0xc6,0xd,0x88,0x8,0x4b,0xe3,0x3,0x85,0xb8,
  0xba,0x1c,0x65,0xe6,0xe9,0xd1,0xa8,0xb6,0xba,0x39,0x76,0x11,0xd8,0x0,0x6,0xe6,
  0x71,0xd6,0x34,0x51,0x18,0x77,0x86,0x65,0x1,0x24,0x78,0xc4,0x93,0xe9,0x4c,0x3b,
  0x25,0x2b,0xb7,0xf9,0xc2,0xf6,0x68,0x23,0xa8,0x61,0x9c,0x2c,0xa3,0xb3,0xdf,0xf4,
  0x51,0x20,0x3c,0x9a,0x1b,0x34,0xaa,0xc8,0xa1,0x36,0x25,0x99,0x22,0x1e,0x5f,0x56,
  0xb,0xdd,0xf,0xdd,0x2,0x1c,0xea,0xc4,0xe1,0xb5,0x4f,0xa9,0xd,0xfd,0x60,0x81,
  0x20,0x70,0xb1,0x2c,0x44,0x49,0x43,0x72,0x8f,0xf3,0xc4,0xf7,0x6a,0x9f,0xa4,0xd2,
  0x51,0x36,0x21,0xde,0xe7,0xb5,0x86,0x21,0x7c,0xfb,0xfe,0xd0,0x10,0x2e,0xc6,0xf2,
  0x36,0x57,0xc9,0x26,0x74,0x69,0x64,0xe2,0xd6,0x56,0x45,0x52,0x25,0xd2,0x83,0xd9,
  0x4f,0x1d,0xfa,0xa6,0x88,0x3a,0x7,0xe9,0x49,0xce,0xa3,0x82,0x6c,0xc7,0xc,0xed,
  0xaf,0xb3,0x86,0xf7,0x28,0x79,0x35,0x55,0xe9,0xda,0xcd,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // kirigami
  0x0,0x8,
  0x0,0x8f,0xda,0x79,
  0x0,0x6b,
  0x0,0x69,0x0,0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,0x6d,0x0,0x69,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/kirigami
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/kirigami/qmldir
  0x0,0x0,0x0,0x44,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xa9,0x1f,0x9c,0x60,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigami)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigami)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigami)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigami)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigami)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigami)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> kirigami-6.22.0-2.gpkg.tar: image/usr/src/debug/kde-frameworks/kirigami-6.22.0/kirigami-6.22.0_build/src/.qt/rcc/qrc_qmake_org_kde_kirigami.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0x7d,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x8c,0xb,0x9d,0x1b,0x0,0xd6,0xe0,0x5e,0x1e,0x10,0x77,0x1b,
  0x47,0x7b,0x89,0x9b,0xac,0xf8,0x84,0x26,0xa9,0x4f,0xb4,0x98,0x29,0x26,0xc0,0xc,
  0x0,0x6c,0xa,0xbd,0xaa,0xd6,0x55,0x55,0xf8,0xea,0xaa,0x54,0x0,0x57,0x0,0x57,
  0x0,0xd1,0x19,0x95,0x8,0xe3,0x2d,0x33,0x33,0x4e,0xbe,0xb8,0xda,0x3e,0x4a,0xce,
  0xcd,0x4f,0xda,0xd0,0x5b,0x79,0x2a,0xdc,0xde,0x47,0xe2,0xc9,0x19,0x7f,0xf6,0xe,
  0x9a,0xda,0x5a,0x35,0xdf,0xb5,0x8c,0x29,0xd9,0xd9,0xa8,0x72,0x50,0xe4,0xd5,0x4e,
  0x13,0xb3,0x99,0x46,0x29,0xb5,0x31,0x47,0x45,0x86,0x5b,0x6b,0x93,0xc2,0x63,0xe2,
  0xe6,0xc2,0xd7,0x29,0x8a,0xdc,0x14,0x67,0xa,0xf9,0x59,0x54,0xed,0x13,0x55,0xf0,
  0xdd,0x6d,0x6f,0xcf,0xb3,0x92,0x29,0x99,0xb2,0x1a,0x97,0xb6,0x2f,0xed,0xf6,0xc7,
  0x36,0x73,0x37,0xb4,0xd1,0x2c,0x54,0xc,0x8c,0xdc,0x7a,0x79,0x43,0xa6,0x69,0x4b,
  0xfa,0x8d,0x93,0xf6,0x2f,0xe9,0x52,0xf2,0x17,0xf9,0xf3,0xfb,0x74,0x23,0x8a,0x71,
  0x6b,0x9a,0x62,0x62,0xfa,0x53,0x5e,0xa,0xca,0x1,0x2a,0x81,0x8b,0xce,0x13,0x53,
  0x50,0x96,0x65,0xc1,0x77,0xab,0xb3,0x91,0x35,0x47,0x56,0xc2,0xfd,0x82,0xf6,0x35,
  0xaa,0x9b,0x41,0xa7,0x76,0xad,0xda,0xa9,0xa4,0xf6,0x9f,0x1,0x0,0x41,0xef,0xa5,
  0x94,0x89,0x6d,0xbb,0xc6,0xa1,0x4b,0x15,0x32,0x49,0x2d,0xe,0xe1,0x6,0xd9,0xd6,
  0xce,0x30,0x6d,0x3f,0x9c,0xa0,0x3d,0xb4,0x98,0xb6,0xb,0xb4,0x3b,0xc6,0x1,0x2,
  0xd8,0x6e,0xde,0x7b,0x49,0x4a,0x77,0x8,0x61,0xaf,0xeb,0xc,0xbd,0xfc,0xe8,0xef,
  0x44,0x9f,0x73,0x5b,0x88,0xa2,0x2b,0xbc,0x2e,0xda,0x9d,0xe3,0x8,0xfd,0xa2,0x46,
  0xe0,0x42,0x95,0x72,0x2b,0x1b,0xb9,0xa3,0xa4,0xb4,0xec,0x91,0x6e,0xf0,0x5e,0x19,
  0x81,0x6c,0x67,0x14,0x35,0xdd,0x1f,0x92,0x8e,0xb6,0xf9,0x43,0xb6,0x4f,0x73,0x23,
  0xad,0xd7,0xab,0xdd,0x27,0xbc,0xb2,0xed,0xb1,0xa7,0xfb,0xb3,0xf9,0x31,0xe3,0x92,
  0x1c,0xfe,0xa2,0x24,0x96,0xbc,0xd1,0xbd,0x61,0x7e,0x1b,0xdb,0x7c,0x79,0xa5,0xe4,
  0x4f,0x43,0x9b,0x85,0xcf,0xd1,0xd8,0x9e,0xcc,0x79,0x71,0xf3,0x87,0x22,0x4c,0x17,
  0xbd,0x29,0x68,0x1b,0xb,0x35,0x93,0xfc,0xc6,0xa8,0xb,0x69,0x6d,0x71,0x2b,0xad,
  0xf1,0x59,0xeb,0x8d,0xb4,0x6e,0x2e,0x80,0xf7,0xa8,0x81,0x12,0xd,0xc9,0x8c,0x24,
  0x49,0x65,0xe3,0x30,0x44,0x40,0x1c,0x45,0xe3,0x36,0x31,0x18,0xc8,0x31,0x22,0xd,
  0x22,0x35,0x23,0x23,0x41,0x14,0x26,0x49,0xa,0xcb,0x1,0x59,0xcb,0x82,0x1,0xa8,
  0x50,0x2b,0xcc,0x75,0xf3,0xe1,0x16,0x8d,0x76,0x5f,0xc5,0x83,0xfa,0x40,0x3f,0x21,
  0x37,0x14,0x49,0x85,0xff,0xc5,0x8b,0x7b,0xa5,0xc2,0x77,0x14,0xa8,0x10,0x4e,0xe9,
  0x2d,0x30,0xaf,0xd8,0xc1,0x4d,0x38,0x36,0xfc,0x3b,0x43,0xf5,0x62,0x88,0x1f,0x75,
  0xe2,0x1a,0xca,0xa7,0x2d,0x77,0xbf,0xc1,0xdf,0xc0,0x1d,0x95,0x44,0x44,0x51,0x2,
  0xc2,0x89,0x5e,0x50,0x54,0x99,0xb4,0x5b,0x77,0x3a,0x4c,0x6,0xc2,0x70,0x21,0xd7,
  0x46,0x96,0xe1,0x25,0x4c,0x51,0x43,0xd3,0x90,0xf2,0xd4,0x85,0xfb,0xf6,0xb8,0x83,
  0xf9,0x91,0x92,0xf0,0x8f,0x8,0x41,0xe7,0x88,0x4,0x76,0xb0,0xa,0xb5,0xdc,0xb9,
  0xe1,0x8c,0x13,0xad,0x24,0x89,0xc3,0x31,0x0,0x1b,0x20,0x51,0x3f,0x61,0x20,0x39,
  0x18,0x58,0x6e,0x2,0xe2,0x39,0xf8,0xb,0x63,0x3e,0xc1,0x90,0x16,0x49,0x86,0xf7,
  0x8c,0x66,0x6b,0xcc,0x5b,0xf2,0xce,0x9f,0x8a,0x3f,0x88,0x7f,0x35,0xfb,0x9,0xa,
  0x2c,0xf9,0xd5,0x20,0xa,0x5,0x77,0xa,0x11,0x90,0x70,0xf6,0xe,0x3b,0xb1,0xe1,
  0x92,0x7c,0x64,0xaa,0x70,0xd9,0x48,0x55,0xb3,0xc5,0x99,0xc2,0xeb,0x18,0xc,0x91,
  0x71,0xfd,0xbc,0x5d,0x73,0x9a,0x42,0xea,0x6e,0x27,0x69,0x98,0xa9,0xa4,0xf1,0xc5,
  0x98,0x1f,0xcd,0xb4,0x8,0xb0,0x83,0xe5,0x1d,0x27,0x7f,0x2b,0x5d,0xa2,0x14,0x8e,
  0x53,0x57,0x2d,0xd9,0x3,0x2,0x12,0xc8,0x24,0xee,0x74,0x9e,0xdd,0x8a,0x91,0x39,
  0x55,0x23,0x41,0xd8,0x8e,0xae,0x43,0x90,0x8e,0xb4,0xa0,0xd4,0x72,0x5f,0x3b,0x5e,
  0x48,0x34,0xa7,0xd2,0x52,0xb6,0x77,0xbc,0x78,0xf1,0x2a,0xb3,0x28,0x66,0x96,0xc0,
  0x60,0xbe,0x9d,0xb3,0x31,0x7f,0xc3,0xa7,0x22,0x30,0x2f,0x30,0x2a,0xd0,0xb7,0x23,
  0xe8,0xad,0x86,0x9d,0x6c,0x22,0xd8,0xc6,0xd,0x88,0x8,0x4b,0xe3,0x3,0x85,0xb8,
  0xba,0x1c,0x65,0xe6,0xe9,0xd1,0xa8,0xb6,0xba,0x39,0x76,0x11,0xd8,0x0,0x6,0xe6,
  0x71,0xd6,0x34,0x51,0x18,0x77,0x86,0x65,0x1,0x24,0x78,0xc4,0x93,0xe9,0x4c,0x3b,
  0x25,0x2b,0xb7,0xf9,0xc2,0xf6,0x68,0x23,0xa8,0x61,0x9c,0x2c,0xa3,0xb3,0xdf,0xf4,
  0x51,0x20,0x3c,0x9a,0x1b,0x34,0xaa,0xc8,0xa1,0x36,0x25,0x99,0x22,0x1e,0x5f,0x56,
  0xb,0xdd,0xf,0xdd,0x2,0x1c,0xea,0xc4,0xe1,0xb5,0x4f,0xa9,0xd,0xfd,0x60,0x81,
  0x20,0x70,0xb1,0x2c,0x44,0x49,0x43,0x72,0x8f,0xf3,0xc4,0xf7,0x6a,0x9f,0xa4,0xd2,
  0x51,0x36,0x21,0xde,0xe7,0xb5,0x86,0x21,0x7c,0xfb,0xfe,0xd0,0x10,0x2e,0xc6,0xf2,
  0x36,0x57,0xc9,0x26,0x74,0x69,0x64,0xe2,0xd6,0x56,0x45,0x52,0x25,0xd2,0x83,0xd9,
  0x4f,0x1d,0xfa,0xa6,0x88,0x3a,0x7,0xe9,0x49,0xce,0xa3,0x82,0x6c,0xc7,0xc,0xed,
  0xaf,0xb3,0x86,0xf7,0x28,0x79,0x35,0x55,0xe9,0xda,0xcd,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // kirigami
  0x0,0x8,
  0x0,0x8f,0xda,0x79,
  0x0,0x6b,
  0x0,0x69,0x0,0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,0x6d,0x0,0x69,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/kirigami
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/kirigami/qmldir
  0x0,0x0,0x0,0x44,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0xa,0xe0,0xba,0x14,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigami)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigami)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigami)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigami)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigami)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigami)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
